@@ -58,4 +58,15 @@ void FilterTheBatTest::canNotImportDataUnknowPath()
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
 }
 
+void FilterTheBatTest::canNotImportDataWhenHomeDirSelected()
+{
+    MailImporter::FilterTheBat filter;
+    MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
+    FilterImporterTest *importerTest = new FilterImporterTest(info);
+    filter.setFilterImporter(importerTest);
+    filter.setFilterInfo(info);
+    filter.importMails(QDir::homePath());
+    QVERIFY(importerTest->filterImporterDataList().isEmpty());
+}
+
 QTEST_MAIN(FilterTheBatTest)
